==> mmaid-0.2.9.tar.gz: mmaid-0.2.9/src/export.h <==
/*
    Melody maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __EXPORT_H__
#define __EXPORT_H__


#include "mmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


typedef struct _ExportInfo {
  gboolean hold;    /* ja:既存のタグを保持する */
  gchar *charset;   /* ja:キャラクターセット */
  gint gnum;        /* ja:ジャンル */
} ExportInfo;


/******************************************************************************
*                                                                             *
* ja:エクスポートダイアログ関数群                                             *
*                                                                             *
******************************************************************************/
/*  ja:エクスポートダイアログ表示
    def_charset,デフォルトのキャラクターセット                              */
ExportInfo *
export_dialog (const gchar *def_charset);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __EXPORT_H__ */

==> mmaid-0.4.0.tar.gz: mmaid-0.4.0/src/export.h <==
/*
    Melody maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __EXPORT_H__
#define __EXPORT_H__


#include "mmaid.h"


G_BEGIN_DECLS


typedef struct _ExportInfo {
  gboolean hold;    /* ja:既存のタグを保持する */
  gchar *charset;   /* ja:キャラクターセット */
  gint gnum;        /* ja:ジャンル */
} ExportInfo;


/******************************************************************************
*                                                                             *
* ja:エクスポートダイアログ関数群                                             *
*                                                                             *
******************************************************************************/
/*  ja:エクスポートダイアログ表示
    def_charset,デフォルトのキャラクターセット                              */
ExportInfo *
export_dialog (const gchar *def_charset);


G_END_DECLS


#endif /* __EXPORT_H__ */
